<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>NetFileChooseEdit</name>
    <message>
        <source>All files (*)</source>
        <translation>所有文件 (*)</translation>
    </message>
</context>
<context>
    <name>NetPasswordEdit</name>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
</context>
<context>
    <name>NetUtils</name>
    <message>
        <source>Off</source>
        <translation>已關閉</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>已連接</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP位址衝突</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>正在連接</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>獲取地址中</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>認證中</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>已斷開</translation>
    </message>
</context>
<context>
    <name>PageAirplane</name>
    <message>
        <source>Airplane mode</source>
        <translation>飛行模式</translation>
    </message>
    <message>
        <source>Stop wireless communication</source>
        <translation>停止無線通信</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>打開飛行模式將關閉無線網絡、個人熱點和藍牙功能</translation>
    </message>
</context>
<context>
    <name>PageAppProxy</name>
    <message>
        <source>Application Proxy</source>
        <translation>應用代理</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>設置代理伺服器</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>代理類型</translation>
    </message>
    <message>
        <source>http</source>
        <translation>http</translation>
    </message>
    <message>
        <source>socks4</source>
        <translation>socks4</translation>
    </message>
    <message>
        <source>socks5</source>
        <translation>socks5</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP 地址</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>無效的IP位址</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>無效的端口</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>選填</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>配置好代理後，可在啓動器的應用右鍵菜單查看「使用代理」選項，勾選後即可使用代理</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保 存</translation>
    </message>
</context>
<context>
    <name>PageDSL</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>Set up a dial-up network connection</source>
        <translation>設置撥號網絡連接</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>斷開</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>連接</translation>
    </message>
    <message>
        <source>Add PPPoE connection</source>
        <translation>添加PPPoE連接</translation>
    </message>
</context>
<context>
    <name>PageDSLSettings</name>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>您確定要刪除當前配置嗎？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保 存</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation>%1網絡屬性</translation>
    </message>
</context>
<context>
    <name>PageDetails</name>
    <message>
        <source>Network Details</source>
        <translation>網絡詳情</translation>
    </message>
    <message>
        <source>View all network configurations</source>
        <translation>查看所有網絡配置</translation>
    </message>
    <message>
        <source>Details has been copied</source>
        <translation>信息已複製</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全選</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>網絡檢測</translation>
    </message>
</context>
<context>
    <name>PageHotspot</name>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2個人版</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3個人版</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>不指定設備</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>個人熱點</translation>
    </message>
    <message>
        <source>Share the network</source>
        <translation>共享網絡</translation>
    </message>
    <message>
        <source>My Hotspot</source>
        <translation>我的熱點</translation>
    </message>
    <message>
        <source>Edit My Hotspot</source>
        <translation>編輯我的熱點</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>名稱（SSID）</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>安全</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>頻段</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保 存</translation>
    </message>
    <message>
        <source>Shared Settings</source>
        <translation>共享設置</translation>
    </message>
    <message>
        <source>Hotspot Sharing Device</source>
        <translation>共享熱點的網卡設備</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable Airplane Mode first and then enable the wireless network adapter.</source>
        <translation>若要使用個人熱點功能，請先退出飛行模式，再啓用無線網卡。</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
        <translation>若要使用個人熱點功能，請先退出&lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;飛行模式&lt;/a&gt;，再啓用無線網卡。</translation>
    </message>
    <message>
        <source>Enable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Wireless Network Adapter&lt;/a&gt; first if you want to use the personal hotspot.</source>
        <translation>若要使用個人熱點功能，請先啓用&lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;無線網卡&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>PageSettings</name>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>您確定要刪除當前配置嗎？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保 存</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation>%1網絡屬性</translation>
    </message>
</context>
<context>
    <name>PageSystemProxy</name>
    <message>
        <source>System Proxy</source>
        <translation>系統代理</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>設置代理伺服器</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>代理類型</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>配置URL</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP代理</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS代理</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP代理</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS代理</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>忽略以上主機和域的代理配置</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保 存</translation>
    </message>
</context>
<context>
    <name>PageVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Connect, add, import</source>
        <translation>連接、添加、導入</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>斷開</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>連接</translation>
    </message>
    <message>
        <source>Add VPN</source>
        <translation>添加VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>導入VPN</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>導入錯誤</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>導入文件錯誤</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>PageVPNSettings</name>
    <message>
        <source>VPN Type</source>
        <translation>VPN類型</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>您確定要刪除當前配置嗎？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>導 出</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保 存</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation>%1網絡屬性</translation>
    </message>
</context>
<context>
    <name>PageWiredDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>連接、編輯網絡設置</translation>
    </message>
    <message>
        <source>Plug in the network cable first</source>
        <translation>請您先插入網線！</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>斷開</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>連接</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>添加網絡設置</translation>
    </message>
</context>
<context>
    <name>PageWirelessDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>連接、編輯網絡設置</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>斷開</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>連接</translation>
    </message>
    <message>
        <source>Other Networks</source>
        <translation>其他網絡</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a wireless network</source>
        <translation>若要使用無線網絡功能，請先關閉飛行模式</translation>
    </message>
    <message>
        <source>Disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>若要使用無線網絡功能，請先關閉&lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;飛行模式&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>若要連接並使用無線網絡功能，請先關閉熱點分享</translation>
    </message>
    <message>
        <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>若要連接並使用無線網絡功能，請先&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;關閉熱點分享&lt;/a&gt;</translation>
    </message>
    <message>
        <source>My Networks</source>
        <translation>我的網絡</translation>
    </message>
</context>
<context>
    <name>SectionDNS</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編輯</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>無效的IP位址</translation>
    </message>
</context>
<context>
    <name>SectionDevice</name>
    <message>
        <source>Not Bind</source>
        <translation>不指定設備</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Ethernet</source>
        <translation>以太網</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>設備MAC地址</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>克隆MAC地址</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>自定義MTU</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>頻段</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SectionGeneric</name>
    <message>
        <source>General</source>
        <translation>通用</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>名稱（SSID）</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>自動連接</translation>
    </message>
</context>
<context>
    <name>SectionIPv4</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編輯</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>禁用</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>方法</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>僅用於相對應的網絡上的資源</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP 地址</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>無效的IP位址</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>子網掩碼</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>網關</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>無效的子網掩碼</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無效的網關地址</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>重複的IP位址</translation>
    </message>
</context>
<context>
    <name>SectionIPv6</name>
    <message>
        <source>Disabled</source>
        <translation>禁用</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編輯</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>方法</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>僅用於相對應的網絡上的資源</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP 地址</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>無效的IP位址</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>前綴</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>網關</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>無效的子網掩碼</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>重複的IP位址</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無效的網關地址</translation>
    </message>
</context>
<context>
    <name>SectionPPP</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>使用MPPE點到點加密</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>使用128位MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>使用帶狀態的MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>拒絕EAP認證</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>拒絕PAP認證</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>拒絕CHAP認證</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>拒絕MSCHAP認證</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>拒絕MSCHAPv2認證</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>無BSD數據壓縮</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>無Deflate數據壓縮</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>無TCP頭壓縮</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>發送PPP迴響包</translation>
    </message>
</context>
<context>
    <name>SectionPPPOE</name>
    <message>
        <source>PPPoE</source>
        <translation>撥號</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>服務</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
</context>
<context>
    <name>SectionSecret</name>
    <message>
        <source>Security</source>
        <translation>安全</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>隧道TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>受保護的EAP</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2個人版</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2企業版</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3個人版</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP認證</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>身份</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>密碼選項</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>僅為該用户存儲密碼</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>存儲所有用户密碼</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>總是詢問</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>密鑰</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>私鑰密碼</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>安全認證類型</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>共享密鑰</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>開放式系統</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>私鑰</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>匿名身份</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>自動PAC配置</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>已禁用</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>匿名</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>已認證</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>兼有</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC文件</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA證書</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>用户證書</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP版本</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>版本0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>版本1</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>內部認證</translation>
    </message>
</context>
<context>
    <name>SectionVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>所有文件 (*)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>無效的網關地址</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>網關</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA證書</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>代理</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>允許思科安全桌面木馬</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD 腳本</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>認證類型</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>私鑰</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH代理</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>智能卡</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>預共享密鑰</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>用户證書</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>為密鑰口令句使用FSID</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>證書（TLS）</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>證書和密碼（TLS）</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>靜態密鑰</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>密碼選項</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>已保存的</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>總是詢問</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>不要求</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>私鑰密碼</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>自定義密鑰方向</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>密鑰方向</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>遠程IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>本地IP</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT域</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>請求內部IP位址</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>強制使用UDP封裝</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>使用IP壓縮</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>啓用自定義加密方案</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>組名</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>組密碼</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>使用混合認證</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA文件</translation>
    </message>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>使用MPPE點到點加密</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>安全</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>都可用（默認）</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40位（較安全）</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128位（最安全）</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>使用帶狀態的MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>拒絕EAP認證</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>拒絕PAP認證</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>拒絕CHAP認證</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>拒絕MSCHAP認證</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>拒絕MSCHAPv2認證</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>無BSD數據壓縮</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>無Deflate數據壓縮</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>無TCP頭壓縮</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>無協議字段壓縮</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>無地址/控制壓縮</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>發送PPP迴響包</translation>
    </message>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>啓用IPsec</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>組ID</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>密鑰交換協議</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>安全封裝協議</translation>
    </message>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN高級選項</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>自定義網關端口</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>網關端口</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>自定義重新協商間隔</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>重新協商間隔</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>使用LZO壓縮</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>使用TCP連接</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>使用TAP設備</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>自定義最大傳輸單元(MTU)</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>自定義UDP數據報段長度</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP數據報段長度</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>限制隧道TCP最大段長度(MSS)</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>隨機遠程主機</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>域</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>供應商</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>思科（默認）</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>網屏</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>加密</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>安全（默認）</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>弱</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT遍歷</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T若可用（默認）</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>總是NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>思科UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>已禁用</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH 組</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Group 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Group 2（默認）</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Group 5</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>前向保密</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>伺服器（默認）</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Group 2</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>本地端口</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>禁用死端檢測</translation>
    </message>
    <message>
        <source>VPN Security</source>
        <translation>VPN安全</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>加密</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>默認</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
    <message>
        <source>RSA MD-4</source>
        <translation>RSA MD-4</translation>
    </message>
    <message>
        <source>MD-5</source>
        <translation>MD-5</translation>
    </message>
    <message>
        <source>SHA-1</source>
        <translation>SHA-1</translation>
    </message>
    <message>
        <source>SHA-224</source>
        <translation>SHA-224</translation>
    </message>
    <message>
        <source>SHA-256</source>
        <translation>SHA-256</translation>
    </message>
    <message>
        <source>SHA-384</source>
        <translation>SHA-384</translation>
    </message>
    <message>
        <source>SHA-512</source>
        <translation>SHA-512</translation>
    </message>
    <message>
        <source>RIPEMD-160</source>
        <translation>RIPEMD-160</translation>
    </message>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN代理</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>代理類型</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>伺服器地址</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>失敗時重試</translation>
    </message>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS 認證</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>主題匹配</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>遠程證書類型</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>客户端</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>伺服器</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>密鑰文件</translation>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SystemProxyConfigItem</name>
    <message>
        <source>Optional</source>
        <translation>選填</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation>需要認證</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>若要使用無線網絡功能，請先關閉 &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;飛行模式&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>IP衝突</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>網絡</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>有線連接 %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE連接 %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>正在連接「%1」</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>「%1」已連接</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>「%1」已斷開連接</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>無法連接「%1」，請檢查您的路由器或網線。</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>無法連接「%1」，請靠近無線路由器</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>連接失敗，無法連接「%1」，密碼錯誤</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>連接「%1」需要密碼</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>找不到無線網絡「%1」</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>要連接「%1」，請在登錄後設置您的身份驗證信息</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>系統代理</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>VPN配置未連接或連接失敗。請&lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;前往控制中心&lt;/a&gt;進行檢查。</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>有線網絡</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>無線網絡</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>連接到隱藏網絡</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>我的網絡</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>其他網絡</translation>
    </message>
</context>
<context>
    <name>network</name>
    <message>
        <source>Network</source>
        <translation>網絡</translation>
    </message>
</context>
<context>
    <name>networkMain</name>
    <message>
        <source>Connection settings</source>
        <translation>連接設置</translation>
    </message>
    <message>
        <source>Related Settings</source>
        <translation>相關設置</translation>
    </message>
</context>
</TS>